==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/ja-sjis/xtselstrHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "ɂs"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define KEYT "L[ږXg"
#define KEYC "PʂƂȂL["

/*-f*/
#define FLDT "ږXg"
#define FLDC "ΏۂƂȂ鍀ږXg"
#define FLDF NULL

/*-v*/
#define VALT ""
#define VALC "-fŎw肵ڂ̒lAŎw肵񃊃Xg̈Ƀ}b`ΑI"

/*-F*/
#define ANDT "ڊAND"
#define ANDC "-fŕڂw肵ꍇȂSĂ̒lnull̍sB"

/*-R*/
#define ARCT "R[hAND"
#define ARCC "-kw肵ꍇȂSĂ̍snull̍sB"

/*-r*/
#define REVT "]"
#define REVC "폜ł͂ȂIB"

/*-u*/
#define NOFT C_NOFT
#define NOFC C_NOFC

/*-q*/
#define SEQT C_SEQT
#define SEQC C_SEQC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "-fŎw肵ڂ̒lA-vŎw̕񃊃Xg̈Ƀ}b`΁A̍sB"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtselstr -f  -v َq,W[X -i dat.xt -o rsl.xt\n\
xtselstr -k ڋq -f  -v َq,W[X -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtsel,xtcommon"

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\\B                  */
/* o^Ȃ(#define HELPB "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\\B                 */
/* o^Ȃ(#define HELPH "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4-pre4.tar.gz: musashi-core-1.0.4-pre4/help/ja-sjis/xtselstrHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "ɂs"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define KEYT "L[ږXg"
#define KEYC "PʂƂȂL["

/*-f*/
#define FLDT "ږXg"
#define FLDC "ΏۂƂȂ鍀ږXg"
#define FLDF NULL

/*-v*/
#define VALT ""
#define VALC "-fŎw肵ڂ̒lAŎw肵񃊃Xg̈Ƀ}b`ΑI"

/*-F*/
#define ANDT "ڊAND"
#define ANDC "-fŕڂw肵ꍇȂSĂ̒lnull̍sB"

/*-R*/
#define ARCT "R[hAND"
#define ARCC "-kw肵ꍇȂSĂ̍snull̍sB"

/*-r*/
#define REVT "]"
#define REVC "폜ł͂ȂIB"

/*-u*/
#define NOFT C_NOFT
#define NOFC C_NOFC

/*-q*/
#define SEQT C_SEQT
#define SEQC C_SEQC

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "-fŎw肵ڂ̒lA-vŎw̕񃊃Xg̈Ƀ}b`΁A̍sB"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtselstr -f  -v َq,W[X -i dat.xt -o rsl.xt\n\
xtselstr -k ڋq -f  -v َq,W[X -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtsel,xtcommon"

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\B                  */
/* o^Ȃ(#define HELPB "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\B                 */
/* o^Ȃ(#define HELPH "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
